@@ -19,6 +19,7 @@ from configobj import ConfigObj, flatten_errors
 from validate import Validator
 import sys
 import os.path
+import logging
 from pkg_resources import resource_stream
 from gns3converter.adapters import PORT_TYPES
 from gns3converter.models import MODEL_TRANSFORM
@@ -44,6 +45,9 @@ class Converter():
         self.configs = []
         self.images = []
 
+        logging.getLogger(__name__)
+        logging.debug('Topology file: {}'.format(self._topology))
+
     def read_topology(self):
         """
         Read the ini-style topology file using ConfigObj
@@ -63,16 +67,16 @@ class Converter():
                                    list_values=False,
                                    encoding='utf-8')
             except SyntaxError:
-                print('Error loading .net file')
+                logging.error('Error loading .net file')
                 exit()
         except IOError:
-            print('Can\'t open topology file')
+            logging.error('Cannot open topology file')
             exit()
 
         vtor = Validator()
         res = config.validate(vtor, preserve_errors=True)
-        if res and self._debug:
-            print('Validation Passed')
+        if res:
+            logging.debug('Validation passed')
         elif not res:
             for entry in flatten_errors(config, res):
                 # each entry is a tuple
@@ -154,12 +158,17 @@ class Converter():
                 tmp_node = Node({}, self.port_id)
             # Start building the structure
             tmp_node.node['properties']['name'] = device
-            tmp_node.node['label']['text'] = device
             tmp_node.node['id'] = devices[device]['node_id']
             tmp_node.node['x'] = devices[device]['x']
             tmp_node.node['y'] = devices[device]['y']
             tmp_node.device_info['type'] = devices[device]['type']
 
+            # Node Label
+            tmp_node.node['label']['text'] = device
+            if 'hx' in devices[device] and 'hy' in devices[device]:
+                tmp_node.node['label']['x'] = devices[device]['hx']
+                tmp_node.node['label']['y'] = devices[device]['hy']
+
             if 'model' in devices[device]:
                 tmp_node.device_info['model'] = devices[device]['model']
             else:
@@ -199,6 +208,10 @@ class Converter():
                 except RuntimeError as err:
                     print(err)
 
+            elif tmp_node.device_info['type'] == 'FrameRelaySwitch':
+                tmp_node.process_mappings()
+                pass
+
             # Get the data we need back from the node instance
             self.links.extend(tmp_node.links)
             self.configs.extend(tmp_node.config)
