@@ -14,10 +14,15 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 import json
 import os
-import sys
 import shutil
 import argparse
+import logging
 from gns3converter import Converter, __version__
+from gns3converter.topology import JSONTopology
+
+LOG_MSG_FMT = '[%(levelname)1.1s %(asctime)s %(module)s:%(lineno)d] ' \
+              '%(message)s'
+LOG_DATE_FMT = '%y%m%d %H:%M:%S'
 
 
 def main():
@@ -29,52 +34,39 @@ def main():
     arg_parse = setup_argparse()
     args = arg_parse.parse_args()
 
+    if args.debug:
+        logging_level = logging.DEBUG
+    else:
+        logging_level = logging.WARNING
+
+    logging.basicConfig(level=logging_level,
+                        format=LOG_MSG_FMT, datefmt=LOG_DATE_FMT)
+
+    logging.getLogger(__name__)
+
     # Create a new instance of the the Converter
     gns3_conv = Converter(topology_abspath(args.topology), args.debug)
     # Read the old topology
     old_top = gns3_conv.read_topology()
+    new_top = JSONTopology()
 
     # Process the sections
     (devices, conf, artwork) = gns3_conv.process_topology(old_top)
 
     # Generate the nodes
-    topology_nodes = gns3_conv.generate_nodes(devices, conf)
+    new_top.nodes = gns3_conv.generate_nodes(devices, conf)
     # Generate the links
-    topology_links = gns3_conv.generate_links(topology_nodes)
+    new_top.links = gns3_conv.generate_links(new_top.nodes)
 
-    topology_notes = gns3_conv.generate_notes(artwork['NOTE'])
-    topology_shapes = gns3_conv.generate_shapes(artwork['SHAPE'])
-    topology_images = gns3_conv.generate_images(artwork['PIXMAP'])
+    new_top.notes = gns3_conv.generate_notes(artwork['NOTE'])
+    new_top.shapes = gns3_conv.generate_shapes(artwork['SHAPE'])
+    new_top.images = gns3_conv.generate_images(artwork['PIXMAP'])
 
     # Enter topology name
-    topology_name = name()
-
-    # Build the topology servers data
-    topology_servers = [{'host': '127.0.0.1',
-                         'id': 1,
-                         'local': True,
-                         'port': 8000}]
-    # Compile all the sections ready for output
-    assembled = {'name': topology_name,
-                 'resources_type': 'local',
-                 'topology': {'links': topology_links,
-                              'nodes': topology_nodes,
-                              'servers': topology_servers},
-                 'type': 'topology',
-                 'version': '1.0'}
-
-    if len(topology_notes) > 0:
-        assembled['topology']['notes'] = topology_notes
-
-    if len(topology_shapes['ellipse']) > 0:
-        assembled['topology']['ellipses'] = topology_shapes['ellipse']
-    if len(topology_shapes['rectangle']) > 0:
-        assembled['topology']['rectangles'] = topology_shapes['rectangle']
-    if len(topology_images) > 0:
-        assembled['topology']['images'] = topology_images
+    new_top.name = name(args)
 
     # Save the new topology
-    save(args, topology_name, gns3_conv, assembled)
+    save(args, gns3_conv, new_top)
 
 
 def setup_argparse():
@@ -85,15 +77,17 @@ def setup_argparse():
     :rtype: ArgumentParser
     """
     parser = argparse.ArgumentParser(
-        formatter_class=argparse.RawDescriptionHelpFormatter,
         description='Convert old ini-style GNS3 topologies (<=0.8.7) to '
-                    'the newer\nversion 1+ JSON format')
+                    'the newer version 1+ JSON format')
     parser.add_argument('--version',
                         action='version',
                         version='%(prog)s ' + __version__)
-    parser.add_argument('-o', '--output', help='Output the new topology to '
-                        'this directory')
-    parser.add_argument('topology', help='GNS3 .net topology file')
+    parser.add_argument('-n', '--name', help='Topology name (default uses the '
+                                             'name of the old project '
+                                             'directory)')
+    parser.add_argument('-o', '--output', help='Output directory')
+    parser.add_argument('topology', nargs='?', default='topology.net',
+                        help='GNS3 .net topology file (default: topology.net)')
     parser.add_argument('--debug',
                         help='Enable debugging output',
                         action='store_true')
@@ -111,26 +105,40 @@ def topology_abspath(topology):
     return os.path.abspath(topology)
 
 
-def name():
+def topology_dirname(topology):
     """
-    Input a name to save the converted topology as
+    Get the directory containing the topology file
 
-    :return: Name with spaces replaced by underscores
+    :param str topology: topology file
+    :return: directory which contains the topology file
     :rtype: str
     """
-    topo_name = input('Please enter a name for this topology: ')
-    topo_name = topo_name.replace(' ', '_')
+    return os.path.dirname(topology_abspath(topology))
+
+
+def name(args):
+    """
+    Calculate the name to save the converted topology as
+
+    :return: new topology name
+    :rtype: str
+    """
+    if args.name is not None:
+        logging.debug('topology name supplied')
+        topo_name = args.name
+    else:
+        logging.debug('topology name not supplied')
+        topo_name = os.path.basename(topology_dirname(args.topology))
     return topo_name
 
 
-def save(args, topology_name, converter, conv_topology):
+def save(args, converter, json_topology):
     """
     Save the converted topology
 
     :param args: Program arguments
-    :param topology_name: Name to save topology as
-    :param converter: Converter instance
-    :param conv_topology: The converted topology
+    :param Converter converter: Converter instance
+    :param JSONTopology json_topology: JSON topology layout
     """
     try:
         config_err = False
@@ -140,18 +148,15 @@ def save(args, topology_name, converter, conv_topology):
         else:
             output_dir = os.getcwd()
 
-        topology_dir = os.path.join(output_dir, topology_name)
+        topology_name = json_topology.name
         old_topology_dir = os.path.dirname(topology_abspath(args.topology))
-        topology_files_dir = os.path.join(topology_dir, topology_name +
+        topology_files_dir = os.path.join(output_dir, topology_name +
                                           '-files')
 
         # Prepare the directory structure
-        if not os.path.exists(topology_dir):
-            os.makedirs(topology_files_dir)
-        else:
-            print('E: Topology folder for %s already exists, please choose a'
-                  ' new name' % topology_name)
-            sys.exit(1)
+        if not os.path.exists(output_dir):
+            os.makedirs(output_dir)
+
         # Move the dynamips config files to the new topology folder
         if len(converter.configs) > 0:
             dynamips_config_dir = os.path.join(topology_files_dir, 'dynamips',
@@ -160,17 +165,17 @@ def save(args, topology_name, converter, conv_topology):
             for config in converter.configs:
                 old_config_file = os.path.join(old_topology_dir, config['old'])
                 new_config_file = os.path.join(dynamips_config_dir,
-                                               config['new'])
+                                               os.path.basename(config['new']))
                 if os.path.isfile(old_config_file):
                     # Copy and rename the config
                     shutil.copy(old_config_file, new_config_file)
                 else:
                     config_err = True
-                    print('E: Unable to find %s' % config['old'])
+                    logging.error('Unable to find %s' % config['old'])
 
         # Move the image files to the new topology folder if applicable
         if len(converter.images) > 0:
-            images_dir = os.path.join(topology_dir, topology_name + '-files',
+            images_dir = os.path.join(output_dir, topology_name + '-files',
                                       'images')
             os.makedirs(images_dir)
             for image in converter.images:
@@ -181,24 +186,25 @@ def save(args, topology_name, converter, conv_topology):
                     shutil.copy(old_image_file, new_image_file)
                 else:
                     image_err = True
-                    print('E: Unable to find %s' % old_image_file)
+                    logging.error('Unable to find %s' % old_image_file)
 
         if config_err:
-            print('W: Some router startup configurations could not be found\n'
-                  '   to be copied to the new topology')
+            logging.warning('Some router startup configurations could not be '
+                            'found to be copied to the new topology')
 
         if image_err:
-            print('W: Some images could not be found to be copied to the \n'
-                  '   new topology')
+            logging.warning('Some images could not be found to be copied to '
+                            'the new topology')
 
         filename = '%s.gns3' % topology_name
-        file_path = os.path.join(topology_dir, filename)
+        file_path = os.path.join(output_dir, filename)
         with open(file_path, 'w') as file:
-            json.dump(conv_topology, file, indent=4, sort_keys=True)
+            json.dump(json_topology.get_topology(), file, indent=4,
+                      sort_keys=True)
             print('Your topology has been converted and can found in:\n'
-                  '     %s' % topology_dir)
+                  '     %s' % output_dir)
     except OSError as error:
-        print(error)
+        logging.error(error)
 
 
 if __name__ == '__main__':
